==> magics++_2.8.0.dfsg.orig.tar.gz: magics++-2.8.0.dfsg/src/visualisers/SymbolPlotting.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file SymbolPlotting.h
    \brief Definition of the Template class SymbolPlotting.
    
    Magics Team - ECMWF 2004
    
    Started: Mon 19-Jan-2004
    
    Changes:
    
*/

#ifndef SymbolPlotting_H
#define SymbolPlotting_H

#include "magics.h"

#include "SymbolPlottingAttributes.h"
#include "Visdef.h"
#include "PointsHandler.h"
#include "Symbol.h"

namespace magics {

class ProgressObject;

template <class P>
class SymbolPlotting: public SymbolPlottingAttributes, public Visdef<P> {

public:
	SymbolPlotting();
	virtual ~SymbolPlotting();

    // Implements the Visualiser Interface...
   
 
    virtual void operator()(Data<P>&, BasicGraphicsObjectContainer&);
    virtual void visit(LegendVisitor&);
    void operator()(const PaperPoint&, BasicGraphicsObjectContainer&) const; 
    
    
    void set(const map<string, string>& map ) { SymbolPlottingAttributes::set(map); }
    void set(const XmlNode& node ) { SymbolPlottingAttributes::set(node); }

protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 
     
     mutable map<SymbolProperties, Symbol* >            symbols_;
     typename map<SymbolProperties, Symbol* >::iterator current_;
     mutable vector<Text* >                             texts_;
    

private:
    //! Copy constructor - No copy allowed
	SymbolPlotting(const SymbolPlotting&);
    //! Overloaded << operator to copy - No copy allowed
	SymbolPlotting& operator=(const SymbolPlotting&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const SymbolPlotting<P>& p)
		{ p.print(s); return s; }

};

} // namespace magics

#include "SymbolPlotting.cc"
#endif

==> magics++_2.18.15.orig.tar.gz: magics++-2.18.15/src/visualisers/SymbolPlotting.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file SymbolPlotting.h
    \brief Definition of the Template class SymbolPlotting.
    
    Magics Team - ECMWF 2004
    
    Started: Mon 19-Jan-2004
    
    Changes:
    
*/

#ifndef SymbolPlotting_H
#define SymbolPlotting_H

#include "magics.h"

#include "SymbolPlottingAttributes.h"
#include "Visdef.h"
#include "PointsHandler.h"
#include "Symbol.h"

namespace magics {

class ProgressObject;


class SymbolPlotting: public SymbolPlottingAttributes, public Visdef {

public:
	SymbolPlotting();
	virtual ~SymbolPlotting();


    // Implements the Visualiser Interface...
   
 
    virtual void operator()(Data&, BasicGraphicsObjectContainer&);
    virtual void visit(Data&, LegendVisitor&);
    bool needLegend() { return legend_; }
    virtual void visit(Data&, HistoVisitor&);
    void operator()(const PaperPoint&, BasicGraphicsObjectContainer&) const; 
    
    
    void set(const map<string, string>& map ) { SymbolPlottingAttributes::set(map); }
    void set(const XmlNode& node ) { SymbolPlottingAttributes::set(node); }

protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 
     
     mutable map<SymbolProperties, Symbol* >            symbols_;
     map<SymbolProperties, Symbol* >::iterator current_;
     mutable vector<Text* >                             texts_;
     vector<string>::iterator text_;
    

private:
    //! Copy constructor - No copy allowed
	SymbolPlotting(const SymbolPlotting&);
    //! Overloaded << operator to copy - No copy allowed
	SymbolPlotting& operator=(const SymbolPlotting&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const SymbolPlotting& p)
		{ p.print(s); return s; }

};

} // namespace magics


#endif
